piep
====

.. image:: http://gfxmonk.net/dist/status/project/piep.png

Bringing the power of python to stream editing
----------------------------------------------

| Online documentation:
| http://gfxmonk.net/dist/doc/piep/
|
| Source Code / Issues:
| https://github.com/gfxmonk/piep/
|
| Pypi:
| http://pypi.python.org/pypi/piep

HACKING
-------

Please add tests for any new functionality.

Run the tests with ``make test``.
